@@ -178,12 +178,12 @@ TEST(UtilityTest, ConvertMsgsPlaneToMath)
 /////////////////////////////////////////////////
 TEST(MsgsTest, ConvertMathInertialToMsgs)
 {
-  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg = msgs::Convert(
-      ignition::math::Inertiald(
-        ignition::math::MassMatrix3d(12.0,
-          ignition::math::Vector3d(2, 3, 4),
-          ignition::math::Vector3d(0.1, 0.2, 0.3)),
+      math::Inertiald(
+        math::MassMatrix3d(12.0,
+          math::Vector3d(2, 3, 4),
+          math::Vector3d(0.1, 0.2, 0.3)),
         pose));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
@@ -199,12 +199,12 @@ TEST(MsgsTest, ConvertMathInertialToMsgs)
 /////////////////////////////////////////////////
 TEST(MsgsTest, ConvertMsgsInertialToMath)
 {
-  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg = msgs::Convert(
-      ignition::math::Inertiald(
-        ignition::math::MassMatrix3d(12.0,
-          ignition::math::Vector3d(2, 3, 4),
-          ignition::math::Vector3d(0.1, 0.2, 0.3)),
+      math::Inertiald(
+        math::MassMatrix3d(12.0,
+          math::Vector3d(2, 3, 4),
+          math::Vector3d(0.1, 0.2, 0.3)),
         pose));
   auto inertial = msgs::Convert(msg);
 
@@ -222,9 +222,9 @@ TEST(MsgsTest, ConvertMsgsInertialToMath)
 TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
 {
   msgs::Inertial msg = msgs::Convert(
-      ignition::math::MassMatrix3d(12.0,
-        ignition::math::Vector3d(2, 3, 4),
-        ignition::math::Vector3d(0.1, 0.2, 0.3)));
+      math::MassMatrix3d(12.0,
+        math::Vector3d(2, 3, 4),
+        math::Vector3d(0.1, 0.2, 0.3)));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
   EXPECT_DOUBLE_EQ(2.0, msg.ixx());
@@ -233,7 +233,7 @@ TEST(MsgsTest, ConvertMathMassMatrix3ToMsgs)
   EXPECT_DOUBLE_EQ(0.1, msg.ixy());
   EXPECT_DOUBLE_EQ(0.2, msg.ixz());
   EXPECT_DOUBLE_EQ(0.3, msg.iyz());
-  EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
+  EXPECT_EQ(math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
 /////////////////////////////////////////////////
@@ -563,13 +563,13 @@ TEST(UtilityTest, SetPlane)
 /////////////////////////////////////////////////
 TEST(MsgsTest, SetInertial)
 {
-  const auto pose = ignition::math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
+  const auto pose = math::Pose3d(5, 6, 7, 0.4, 0.5, 0.6);
   msgs::Inertial msg;
-  msgs::Set(&msg, ignition::math::Inertiald(
-      ignition::math::MassMatrix3d(
+  msgs::Set(&msg, math::Inertiald(
+      math::MassMatrix3d(
         12.0,
-        ignition::math::Vector3d(2, 3, 4),
-        ignition::math::Vector3d(0.1, 0.2, 0.3)),
+        math::Vector3d(2, 3, 4),
+        math::Vector3d(0.1, 0.2, 0.3)),
       pose));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
@@ -586,10 +586,10 @@ TEST(MsgsTest, SetInertial)
 TEST(MsgsTest, SetMassMatrix3)
 {
   msgs::Inertial msg;
-  msgs::Set(&msg, ignition::math::MassMatrix3d(
+  msgs::Set(&msg, math::MassMatrix3d(
         12.0,
-        ignition::math::Vector3d(2, 3, 4),
-        ignition::math::Vector3d(0.1, 0.2, 0.3)));
+        math::Vector3d(2, 3, 4),
+        math::Vector3d(0.1, 0.2, 0.3)));
 
   EXPECT_DOUBLE_EQ(12.0, msg.mass());
   EXPECT_DOUBLE_EQ(2.0, msg.ixx());
@@ -598,7 +598,7 @@ TEST(MsgsTest, SetMassMatrix3)
   EXPECT_DOUBLE_EQ(0.1, msg.ixy());
   EXPECT_DOUBLE_EQ(0.2, msg.ixz());
   EXPECT_DOUBLE_EQ(0.3, msg.iyz());
-  EXPECT_EQ(ignition::math::Pose3d::Zero, msgs::Convert(msg.pose()));
+  EXPECT_EQ(math::Pose3d::Zero, msgs::Convert(msg.pose()));
 }
 
 /////////////////////////////////////////////////
